import 'package:flutter/material.dart';
import 'package:fl_chart/fl_chart.dart';

class BarData extends StatefulWidget {
  const BarData({super.key});

  @override
  State<StatefulWidget> createState() => _BarDataState();
}


class _BarDataState extends State<BarData> {
  static const double barWidth = 30;

  // NB should be rounded to two decimals in server
  // NB should be allocated values dynamically
  // Bar items show data for 10 previous days
  static const barData = <int, List<double>>{
    0: [1.5, 4, 2.5],
    1: [1.8, 5.6, 3],
    2: [1.5, 3.1, 3.5],
    3: [1.5, 1.5, 4],
    4: [2, 2, 5],
    5: [1.2, 1.5, 4.3],
    6: [1.2, 4.8, 5],
  };
  int touchedIndex = -1;

  @override
  void initState() {
    super.initState();
  }

  BarChartGroupData generateGroup(
      int x,
      double value1,
      double value2,
      double value3,
      ) {
    final sum = value1 + value2 + value3;
    final isTouched = touchedIndex == x;
    return BarChartGroupData(
      x: x,
      showingTooltipIndicators: isTouched ? [0] : [],
      barRods: [
        BarChartRodData(
          y: sum,
          width: barWidth,
          borderRadius: const BorderRadius.only(
            topLeft: Radius.circular(6),
            topRight: Radius.circular(6),
          ),
          rodStackItems: [
            BarChartRodStackItem(
              0,
              value1,
              const Color(0xFF13dbff),
            ),
            BarChartRodStackItem(
              value1,
              value1 + value2,
              const Color(0xFF000085),
            ),
            BarChartRodStackItem(
              value1 + value2,
              value1 + value2 + value3,
              Colors.white60,
            ),
          ],
        ),
      ],
    );
  }

  Widget _buildLegendItem(Color color, String text) {
    return Row(
      children: [
        Container(
          width: 20,
          height: 20,
          decoration: BoxDecoration(
            color: color,
            shape: BoxShape.circle,
          ),
        ),
        const SizedBox(width: 8),
        Text(
          text,
          style: const TextStyle(
            fontSize: 14,
            color: Colors.white,
          ),
        ),
      ],
    );
  }


  @override
  Widget build(BuildContext context) {
      return Padding(
        padding: const EdgeInsets.only(top: 16),
        child: Column(
          children: [
            SizedBox(
              width: MediaQuery.of(context).size.width, // Set the desired width
              child: BarChart(
                BarChartData(
                  alignment: BarChartAlignment.center,
                  maxY: 12,
                  minY: 0,
                  titlesData: FlTitlesData(
                    show: true,
                    bottomTitles: SideTitles(
                      showTitles: true,
                      reservedSize: 5,
                      getTextStyles: (value) => const TextStyle(color: Colors.white60),
                    ),
                    leftTitles: SideTitles(
                      showTitles: true,
                      getTextStyles: (value) => const TextStyle(color: Colors.white60),
                      margin: 10,
                      reservedSize: 30,
                      interval: 2,
                    ),
                    rightTitles: SideTitles(
                      showTitles: true,
                      getTextStyles: (value) => const TextStyle(color: Colors.white60),
                      margin: 10,
                      reservedSize: 30,
                      interval: 2,
                    ),
                  ),
                  groupsSpace: 14,
                  gridData: FlGridData(
                    show: true,
                  ),
                  borderData: FlBorderData(
                    show: false,
                  ),
                  barGroups: barData.entries
                      .map(
                        (e) => generateGroup(
                      e.key,
                      e.value[0],
                      e.value[1],
                      e.value[2],
                    ),
                  ).toList(),
                ),
              ),
            ),
            Padding( // Legend items
              padding: const EdgeInsets.only(top: 20),
              child: Center(
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: [
                    _buildLegendItem(Colors.white60, "Snow"),
                    _buildLegendItem(const Color(0xFF13dbff), "Slush ice"),
                    _buildLegendItem(const Color(0xFF000085), "Black ice"),
                  ],
                ),
              ),
            ),
          ],
        ),
      );
   }
}